# coding=utf-8
# *** WARNING: this file was generated by pulumigen. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import importlib
# Export this package's modules as members:
from .kustomize import *
from .provider import *
from .yaml import *

# Make subpackages available:
_submodules = [
    'admissionregistration',
    'apiextensions',
    'apiregistration',
    'apps',
    'auditregistration',
    'authentication',
    'authorization',
    'autoscaling',
    'batch',
    'certificates',
    'coordination',
    'core',
    'discovery',
    'events',
    'extensions',
    'flowcontrol',
    'helm',
    'meta',
    'networking',
    'node',
    'policy',
    'rbac',
    'scheduling',
    'settings',
    'storage',
]
for pkg in _submodules:
    if pkg != 'config':
        importlib.import_module(f'{__name__}.{pkg}')
